/* -*- Mode: C; c-basic-offset: 2; indent-tabs-mode: nil -*-
 *
 * Pigment Render base library
 *
 * Copyright © 2006 Fluendo Embedded S.L. <www.fluendo.com>
 * All rights reserved.
 *
 * This file is available under one of two license agreements.
 *
 * This file is licensed under the GPL version 2. See "LICENSE.GPL" in
 * the root of this distribution including a special exception to use
 * Pigment with Fluendo's plugins.
 *
 * The GPL part of Pigment is also available under a commercial licensing
 * agreement from Fluendo. See "LICENSE.Pigment" in the root directory
 * of this distribution package for details on that license.
 */

#ifndef __PGM_RENDER_LAYOUT_IFACE_H__
#define __PGM_RENDER_LAYOUT_IFACE_H__

#include "pgmrendererror.h"
#include <glib-object.h>

G_BEGIN_DECLS

#define PGM_RENDER_TYPE_LAYOUT_IFACE             (pgm_render_layout_iface_get_type ())
#define PGM_RENDER_LAYOUT_IFACE(obj)             (G_TYPE_CHECK_INSTANCE_CAST((obj), PGM_RENDER_TYPE_LAYOUT_IFACE, PgmRenderLayoutIFace))
#define PGM_RENDER_LAYOUT_IFACE_CLASS(vtable)    (G_TYPE_CHECK_CLASS_CAST((vtable), PGM_RENDER_TYPE_LAYOUT_IFACE, GTypeInterface))
#define PGM_RENDER_IS_LAYOUT_IFACE(obj)          (G_TYPE_CHECK_INSTANCE_TYPE((obj), PGM_RENDER_TYPE_LAYOUT_IFACE))
#define PGM_RENDER_IS_LAYOUT_IFACE_CLASS(vtable) (G_TYPE_CHECK_CLASS_TYPE((vtable), PGM_RENDER_TYPE_LAYOUT_IFACE))
#define PGM_RENDER_LAYOUT_IFACE_GET_CLASS(inst)  (G_TYPE_INSTANCE_GET_INTERFACE((inst), PGM_RENDER_TYPE_LAYOUT_IFACE, PgmRenderLayoutIFaceClass))

/**
 * PgmRenderLayoutAspectStyle: 
 * @PGM_RENDER_LAYOUT_FILLED: Sets the image on the whole surface
 *                            ignoring its pixel-aspect-ratio.
 * @PGM_RENDER_LAYOUT_SCALED: Respects the pixel-aspect-ratio of the
 *                            image adapting the size to the object
 *                            allocated one.
 * @PGM_RENDER_LAYOUT_CENTERED: Centers the image in the middle of the
 *                              object. It crops the image if the
 *                              allocated object size is lesser than
 *                              the image size.
 *
 * The different aspect ratio style.
 */
typedef enum {
  PGM_RENDER_LAYOUT_FILLED   = 0,
  PGM_RENDER_LAYOUT_SCALED   = 1,
  PGM_RENDER_LAYOUT_CENTERED = 2
} PgmRenderLayoutAspectStyle;

typedef struct _PgmRenderLayoutIFace      PgmRenderLayoutIFace;
typedef struct _PgmRenderLayoutIFaceClass PgmRenderLayoutIFaceClass;

struct _PgmRenderLayoutIFaceClass {
  GTypeInterface parent;

  PgmRenderError (*set_size)         (PgmRenderLayoutIFace *layout, gint width, gint height);
  PgmRenderError (*get_size)         (PgmRenderLayoutIFace *layout, gint *width, gint *height);
  PgmRenderError (*set_position)     (PgmRenderLayoutIFace *layout, gint x, gint y);
  PgmRenderError (*get_position)     (PgmRenderLayoutIFace *layout, gint *x, gint *y);
  PgmRenderError (*set_alignment)    (PgmRenderLayoutIFace *layout, gfloat x, gfloat y);
  PgmRenderError (*get_alignment)    (PgmRenderLayoutIFace *layout, gfloat *x, gfloat *y);
  PgmRenderError (*set_aspect_style) (PgmRenderLayoutIFace *layout, PgmRenderLayoutAspectStyle style);
  PgmRenderError (*get_aspect_style) (PgmRenderLayoutIFace *layout, PgmRenderLayoutAspectStyle *style);
  PgmRenderError (*set_aspect_ratio) (PgmRenderLayoutIFace *layout, gfloat ratio);
  PgmRenderError (*get_aspect_ratio) (PgmRenderLayoutIFace *layout, gfloat *ratio);
};

GType          pgm_render_layout_iface_get_type   (void) G_GNUC_CONST;
PgmRenderError pgm_render_layout_set_size         (PgmRenderLayoutIFace *layout, gint width, gint height);
PgmRenderError pgm_render_layout_get_size         (PgmRenderLayoutIFace *layout, gint *width, gint *height);
PgmRenderError pgm_render_layout_set_position     (PgmRenderLayoutIFace *layout, gint x, gint y);
PgmRenderError pgm_render_layout_get_position     (PgmRenderLayoutIFace *layout, gint *x, gint *y);
PgmRenderError pgm_render_layout_set_alignment    (PgmRenderLayoutIFace *layout, gfloat x, gfloat y);
PgmRenderError pgm_render_layout_get_alignment    (PgmRenderLayoutIFace *layout, gfloat *x, gfloat *y);
PgmRenderError pgm_render_layout_set_aspect_style (PgmRenderLayoutIFace *layout, PgmRenderLayoutAspectStyle style);
PgmRenderError pgm_render_layout_get_aspect_style (PgmRenderLayoutIFace *layout, PgmRenderLayoutAspectStyle *style);
PgmRenderError pgm_render_layout_set_aspect_ratio (PgmRenderLayoutIFace *layout, gfloat ratio);
PgmRenderError pgm_render_layout_get_aspect_ratio (PgmRenderLayoutIFace *layout, gfloat *ratio);

G_END_DECLS

#endif /* __PGM_RENDER_LAYOUT_IFACE_H__ */
